@@ -1,17 +1,18 @@
 # model checkers
 import os
-import appdirs
 
+import appdirs
 
 APALACHE = "apalache"
 TLC = "tlc"
 
 DEFAULT_APALACHE_VERSION = "0.25.10"
-DEFAULT_APALACHE_LOCATION = os.path.join(appdirs.user_data_dir(__package__), "checkers")
+DEFAULT_CHECKERS_LOCATION = os.path.join(appdirs.user_data_dir(__package__), "checkers")
+DEFAULT_APALACHE_LOCATION = os.path.join(DEFAULT_CHECKERS_LOCATION, "apalache")
+
 DEFAULT_APALACHE_JAR_FILENAME = f"apalache-{DEFAULT_APALACHE_VERSION}.jar"
 DEFAULT_APALACHE_JAR = os.path.join(
     DEFAULT_APALACHE_LOCATION,
-    "apalache",
     "lib",
     DEFAULT_APALACHE_JAR_FILENAME,
 )
@@ -26,6 +27,17 @@ APALACHE_DEFAULTS = {
     "result_violation_itf_file": "violation.itf.json",
 }
 
+APALACHE_STDOUT = {
+    "CONSTANTS_NOT_INITIALIZED": "CONSTANTS are not initialized",
+    "CONFIG_ERROR": "Configuration error",
+    "INVARIANT_VIOLATION": "InvariantViolation == ",
+}
+
+
+def apalache_release_url(expected_version):
+    return f"https://github.com/informalsystems/apalache/releases/download/v{expected_version}/apalache.zip"
+
+
 DEFAULT_TLC_JAR = "jars/tla2tools-v1.8.0.jar"
 
 PARSE = "parse"
@@ -39,6 +51,7 @@ TYPECHECK_CMD = "typecheck"
 DEFAULT_INVARIANTS = ["Inv"]
 DEFAULT_INIT = "Init"
 DEFAULT_NEXT = "Next"
+DEFAULT_TRACES_DIR = "./traces/"
 
 INIT = "init"
 NEXT = "next"
